OC.L10N.register(
    "core",
    {
    "Please select a file." : "กรุณาเลือกไฟล์",
    "File is too big" : "ไฟล์ใหญ่เกินไป",
    "The selected file is not an image." : "ไฟล์ที่เลือกไม่ใช่รูปภาพ",
    "The selected file cannot be read." : "ไม่สามารถอ่านไฟล์ที่เลือก",
    "The file was uploaded" : "ไฟล์อัปโหลดแล้ว",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "ขนาดไฟล์ที่อัปโหลดมีขนาดเกินค่า upload_max_filesize ที่ระบุไว้ใน php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "ขนาดไฟล์ที่อัปโหลดมีขนาดเกินค่า MAX_FILE_SIZE ที่ระบุไว้ในรูปแบบของ HTML",
    "The file was only partially uploaded" : "ไฟล์ถูกอัปโหลดเพียงบางส่วน",
    "No file was uploaded" : "ไม่มีไฟล์ที่ถูกอัปโหลด",
    "Missing a temporary folder" : "โฟลเดอร์ชั่วคราวเกิดการสูญหาย",
    "Could not write file to disk" : "ไม่สามารถเขียนไฟล์ลงดิสก์",
    "A PHP extension stopped the file upload" : "ส่วนขยาย PHP ได้หยุดการอัปโหลดไฟล์",
    "Invalid file provided" : "ระบุไฟล์ไม่ถูกต้อง",
    "No image or file provided" : "ไม่มีรูปภาพหรือไฟล์ที่ระบุ",
    "Unknown filetype" : "ชนิดไฟล์ที่ไม่รู้จัก",
    "An error occurred. Please contact your admin." : "เกิดข้อผิดพลาด กรุณาติดต่อผู้ดูแลระบบของคุณ",
    "Invalid image" : "รูปภาพไม่ถูกต้อง",
    "No temporary profile picture available, try again" : "ไม่มีรูปภาพโปรไฟล์ชั่วคราว กรุณาลองใหม่อีกครั้ง",
    "No crop data provided" : "ไม่ได้ระบุข้อมูลการครอบตัด",
    "No valid crop data provided" : "ไม่ได้ระบุข้อมูลการครอบตัดที่ถูกต้อง",
    "Crop is not square" : "การครอบตัดไม่เป็นสี่เหลี่ยม",
    "State token does not match" : "โทเค็นสถานะไม่ตรงกัน",
    "Invalid app password" : "รหัสผ่านแอปไม่ถูกต้อง",
    "Could not complete login" : "ไม่สามารถดำเนินการเข้าสู่ระบบ",
    "State token missing" : "โทเค็นของสถานะหายไป",
    "Your login token is invalid or has expired" : "โทเค็นเข้าสู่ระบบของคุณไม่ถูกต้องหรือหมดอายุแล้ว",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "คอมมูนิตี้เวอร์ชันนี้ของ Nextcloud ไม่ได้รับการสนับสนุนและการแจ้งเตือนแบบพุชถูกจำกัด",
    "Login" : "เข้าสู่ระบบ",
    "Password reset is disabled" : "การตั้งรหัสผ่านใหม่ถูกปิดใช้งาน",
    "Could not reset password because the token is expired" : "ไม่สามารถรีเซ็ตรหัสผ่านได้ เนื่องจาก Token หมดอายุ",
    "Could not reset password because the token is invalid" : "ไม่สามารถรีเซ็ตรหัสผ่านได้ เนื่องจาก Token ไม่ถูกต้อง",
    "Password is too long. Maximum allowed length is 469 characters." : "รหัสผ่านยาวเกินไป ความยาวสูงสุดที่อนุญาตคือ 469 ตัวตัวอักษร",
    "%s password reset" : "ตั้งรหัสผ่าน %s ใหม่",
    "Password reset" : "ตั้งรหัสผ่านใหม่",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "คลิกปุ่มด้านล่างเพื่อตั้งรหัสผ่านของคุณใหม่ หากคุณไม่ได้ขอการตั้งรหัสผ่านใหม่ สามารถเพิกเฉยอีเมลนี้",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "คลิกลิงก์ด้านล่างเพื่อตั้งรหัสผ่านของคุณใหม่ หากคุณไม่ได้ขอการตั้งรหัสผ่านใหม่ สามารถเพิกเฉยอีเมลนี้",
    "Reset your password" : "ตั้งรหัสผ่านของคุณใหม่",
    "Task not found" : "ไม่พบงาน",
    "Internal error" : "ข้อผิดพลาดภายใน",
    "Not found" : "ไม่พบสิ่งที่ต้องการ",
    "Requested task type does not exist" : "ไม่มีประเภทงานที่ร้องขออยู่",
    "Necessary language model provider is not available" : "ผู้ให้บริการโมเดลภาษาที่จำเป็นไม่สามารถใช้ได้",
    "No text to image provider is available" : "ไม่มีผู้ให้บริการแปลงข้อความเป็นรูปภาพที่พร้อมใช้งาน",
    "Image not found" : "ไม่พบรูปภาพ",
    "No translation provider available" : "ไม่มีผู้ให้บริการแปลที่พร้อมใช้งาน",
    "Could not detect language" : "ไม่สามารถตรวจจับภาษา",
    "Unable to translate" : "ไม่สามารถแปล",
    "Nextcloud Server" : "เซิร์ฟเวอร์ Nextcloud",
    "Some of your link shares have been removed" : "ลิงก์แชร์บางลิงก์ของคุณถูกลบออก",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "เนื่องจากข้อบกพร่องความปลอดภัย เราจำเป็นต้องลบลิงก์แชร์บางลิงก์ของคุณออก โปรดดูที่ลิงก์สำหรับข้อมูลเพิ่มเติม",
    "The account limit of this instance is reached." : "ถึงขีดจำกัดจำนวนบัญชีของเซิร์ฟเวอร์นี้แล้ว",
    "Learn more ↗" : "เรียนรู้เพิ่มเติม ↗",
    "Preparing update" : "กำลังเตรียมอัปเดต",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "ขั้นตอนการซ่อมแซม:",
    "Repair info:" : "ข้อมูลการซ่อมแซม:",
    "Repair warning:" : "คำเตือนการซ่อมแซม:",
    "Repair error:" : "ข้อผิดพลาดการซ่อมแซม:",
    "Turned on maintenance mode" : "เปิดโหมดการบำรุงรักษาแล้ว",
    "Turned off maintenance mode" : "ปิดโหมดการบำรุงรักษาแล้ว",
    "Maintenance mode is kept active" : "โหมดการบำรุงรักษาถูกเปิดไว้",
    "Updating database schema" : "กำลังอัปเดต Schema ฐานข้อมูล",
    "Updated database" : "อัปเดตฐานข้อมูลแล้ว",
    "Update app \"%s\" from App Store" : "อัปเดตแอป \"%s\" จากร้านค้าแอป",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "กำลังตรวจสอบว่า Schema ฐานข้อมูลสำหรับ %s สามารถอัปเดตได้หรือไม่ (อาจใช้เวลานาน ขึ้นอยู่กับขนาดของฐานข้อมูล)",
    "Updated \"%1$s\" to %2$s" : "อัปเดต \"%1$s\" เป็น %2$s แล้ว",
    "Set log level to debug" : "ตั้งค่าระดับบันทึกเป็น debug",
    "Reset log level" : "ตั้งค่าระดับบันทึกใหม่",
    "Starting code integrity check" : "กำลังเริ่มตรวจสอบความสมบูรณ์ของรหัส",
    "Finished code integrity check" : "ตรวจสอบความสมบูรณ์ของรหัสเสร็จสิ้น",
    "%s (incompatible)" : "%s (เข้ากันไม่ได้)",
    "The following apps have been disabled: %s" : "แอปต่อไปนี้ถูกปิดการใช้งาน: %s",
    "Already up to date" : "ล่าสุดแล้ว",
    "Error occurred while checking server setup" : "เกิดข้อผิดพลาดขณะตรวจสอบการติดตั้งเซิร์ฟเวอร์",
    "For more details see the {linkstart}documentation ↗{linkend}." : "สำหรับข้อมูลเพิ่มเติม โปรดดู{linkstart}เอกสารประกอบ ↗{linkend}",
    "unknown text" : "ข้อความที่ไม่รู้จัก",
    "Hello world!" : "สวัสดีทุกคน!",
    "sunny" : "แดดมาก",
    "Hello {name}, the weather is {weather}" : "สวัสดี {name} สภาพอากาศวันนี้มี{weather}",
    "Hello {name}" : "สวัสดี {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>ผลลัพธ์การค้นหาของคุณ<script>alert(1)</script></strong>",
    "new" : "ใหม่",
    "_download %n file_::_download %n files_" : ["ดาวน์โหลด %n ไฟล์"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "กำลังดำเนินการอัปเกรด หากออกจากหน้านี้อาจเกิดปัญหาในบางสภาพแวดล้อม",
    "Update to {version}" : "อัปเดตเป็น {version}",
    "An error occurred." : "เกิดข้อผิดพลาด",
    "Please reload the page." : "โปรดโหลดหน้าเว็บใหม่",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "การอัปเดตไม่สำเร็จ สำหรับข้อมูลเพิ่มเติม <a href=\"{url}\">ดูโพสต์ของเราในฟอรัม</a>เกี่ยวกับปัญหานี้",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "การอัปเดตไม่สำเร็จ กรุณารายงานปัญหานี้ไปยัง<a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">ชุมชน Nextcloud</a>",
    "Continue to {productName}" : "เข้าสู่ {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["การอัปเดตเสร็จสมบูรณ์ กำลังนำคุณไปที่ {productName} ใน %n วินาที"],
    "Applications menu" : "เมนูแอปพลิเคชัน",
    "Apps" : "แอป",
    "More apps" : "แอปเพิ่มเติม",
    "_{count} notification_::_{count} notifications_" : ["{count} การแจ้งเตือน"],
    "No" : "ไม่",
    "Yes" : "ใช่",
    "Pick start date" : "เลือกวันที่เริ่มต้น",
    "Pick end date" : "เลือกวันที่สิ้นสุด",
    "Search in current app" : "ค้นหาในแอปปัจจุบัน",
    "Clear search" : "ล้างการค้นหา",
    "Search everywhere" : "ค้นหาในทุกที่",
    "Places" : "สถานที่",
    "Date" : "วันที่",
    "Today" : "วันนี้",
    "Last 7 days" : "ภายใน 7 วัน",
    "Last 30 days" : "ภายใน 30 วัน",
    "This year" : "ปีนี้",
    "Last year" : "ปีที่แล้ว",
    "Search people" : "ค้นหาผู้คน",
    "People" : "ผู้คน",
    "Results" : "ผลลัพธ์",
    "Load more results" : "โหลดผลลัพธ์เพิ่มเติม",
    "Searching …" : "กำลังค้นหา …",
    "Start typing to search" : "เริ่มพิมพ์เพื่อค้นหา",
    "Log in" : "เข้าสู่ระบบ",
    "Logging in …" : "กำลังเข้าสู่ระบบ ...",
    "Server side authentication failed!" : "การรับรองความถูกต้องฝั่งเซิร์ฟเวอร์ล้มเหลว!",
    "Please contact your administrator." : "กรุณาติดต่อผู้ดูแลระบบ",
    "Temporary error" : "ข้อผิดพลาดชั่วคราว",
    "Please try again." : "กรุณาลองอีกครั้ง",
    "An internal error occurred." : "เกิดข้อผิดพลาดภายใน",
    "Please try again or contact your administrator." : "กรุณาลองอีกครั้งหรือติดต่อผู้ดูแลระบบ",
    "Password" : "รหัสผ่าน",
    "Log in to {productName}" : "เข้าสู่ระบบไปยัง {productName}",
    "Wrong login or password." : "ล็อกอินหรือรหัสผ่านไม่ถูกต้อง",
    "This account is disabled" : "บัญชีนี้ถูกปิดใช้งาน",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "เราตรวจพบการเข้าสู่ระบบที่ไม่ถูกต้องจากที่อยู่ IP ของคุณหลายครั้ง การเข้าสู่ระบบถัดไปของคุณถูกควบคุมเป็นเวลาอย่างมาก 30 วินาที",
    "Account name or email" : "ชื่อหรืออีเมลบัญชี",
    "Account name" : "ชื่อบัญชี",
    "Log in with a device" : "เข้าสู่ระบบด้วยอุปกรณ์",
    "Login or email" : "ล็อกอินหรืออีเมล",
    "Your account is not setup for passwordless login." : "บัญชีของคุณยังไม่ได้ตั้งค่าการเข้าสู่ระบบแบบไร้รหัสผ่าน",
    "Browser not supported" : "ไม่รองรับเบราว์เซอร์",
    "Passwordless authentication is not supported in your browser." : "เบราว์เซอร์ของคุณไม่รองรับการรับรองความถูกต้องแบบไร้รหัสผ่าน",
    "Your connection is not secure" : "การเชื่อมต่อของคุณไม่ปลอดภัย",
    "Passwordless authentication is only available over a secure connection." : "สามารถใช้การรับรองความถูกต้องแบบไร้รหัสผ่านผ่านการเชื่อมต่อที่ปลอดภัยเท่านั้น",
    "Reset password" : "ตั้งรหัสผ่านใหม่",
    "Couldn't send reset email. Please contact your administrator." : "ไม่สามารถส่งข้อมูลการตั้งค่าไปยังอีเมลของคุณ กรุณาติดต่อผู้ดูแลระบบ",
    "Password cannot be changed. Please contact your administrator." : "ไม่สามารถเปลี่ยนรหัสผ่าน กรุณาติดต่อผู้ดูแลระบบ",
    "Back to login" : "กลับสู่หน้าเข้าสู่ระบบ",
    "New password" : "รหัสผ่านใหม่",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "ไฟล์ของคุณถูกเข้ารหัส คุณจะไม่สามารถรับข้อมูลของคุณกลับมาหลังจากที่ตั้งรหัสผ่านใหม่แล้ว หากคุณไม่แน่ใจว่าควรทำอย่างไร โปรดติดต่อผู้ดูแลระบบของคุณก่อนดำเนินการต่อ ต้องการดำเนินการต่อหรือไม่?",
    "I know what I'm doing" : "ฉันรู้ว่าฉันกำลังทำอะไรอยู่",
    "Resetting password" : "กำลังตั้งรหัสผ่านใหม่",
    "Recommended apps" : "แอปแนะนำ",
    "Loading apps …" : "กำลังโหลดแอป …",
    "Could not fetch list of apps from the App Store." : "ไม่สามารถดึงรายการแอปจากร้านค้าแอป",
    "App download or installation failed" : "การดาวน์โหลดหรือติดตั้งแอปล้มเหลว",
    "Cannot install this app because it is not compatible" : "ไม่สามารถติดตั้งแอปนี้ เนื่องจากแอปนี้เข้ากันไม่ได้",
    "Cannot install this app" : "ไม่สามารถติดตั้งแอปนี้",
    "Skip" : "ข้าม",
    "Installing apps …" : "กำลังติดตั้งแอป …",
    "Install recommended apps" : "ติดตั้งแอปแนะนำ",
    "Distraction free note taking app." : "แอปจดโน้ตแบบไร้สิ่งรบกวน",
    "Settings menu" : "เมนูการตั้งค่า",
    "Avatar of {displayName}" : "อวาตาร์ของ {displayName}",
    "Search contacts" : "ค้นหารายชื่อ",
    "Reset search" : "รีเซ็ตการค้นหา",
    "Search contacts …" : "ค้นหารายชื่อผู้ติดต่อ …",
    "Could not load your contacts" : "ไม่สามารถโหลดรายชื่อผู้ติดต่อ",
    "No contacts found" : "ไม่พบรายชื่อผู้ติดต่อ",
    "Show all contacts" : "แสดงรายชื่อทั้งหมด",
    "Install the Contacts app" : "ติดตั้งแอปรายชื่อ",
    "Loading your contacts …" : "กำลังโหลดรายชื่อผู้ติดต่อของคุณ …",
    "Looking for {term} …" : "กำลังค้นหา {term} …",
    "Search starts once you start typing and results may be reached with the arrow keys" : "การค้นหาจะเริ่มนับจากที่คุณเริ่มพิมพ์ และสามารถเลือกผลลัพธ์ด้วยปุ่มลูกศรได้",
    "Search for {name} only" : "ค้นหาเฉพาะ {name} เท่านั้น",
    "Loading more results …" : "กำลังโหลดผลลัพธ์เพิ่มเติม …",
    "Search" : "ค้นหา",
    "No results for {query}" : "ไม่มีผลลัพธ์สำหรับ {query}",
    "Press Enter to start searching" : "กด Enter เพื่อเริ่มค้นหา",
    "An error occurred while searching for {type}" : "เกิดข้อผิดพลาดขณะค้นหา {type}",
    "Forgot password?" : "ลืมรหัสผ่าน?",
    "Back to login form" : "กลับสู่แบบฟอร์มเข้าสู่ระบบ",
    "Back" : "ย้อนกลับ",
    "Login form is disabled." : "ฟอร์มล็อกอินถูกปิดใช้งาน",
    "Edit Profile" : "แก้ไขโปรไฟล์",
    "You have not added any info yet" : "คุณยังไม่ได้เพิ่มข้อมูลใด ๆ",
    "{user} has not added any info yet" : "{user} ยังไม่ได้เพิ่มข้อมูลใด ๆ",
    "This browser is not supported" : "เบราว์เซอร์นี้ไม่ได้รับการสนับสนุน",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "เบราว์เซอร์ของคุณไม่ได้รับการสนับสนุน กรุณาอัปเกรดเป็นรุ่นที่ใหม่กว่าหรือเบราว์เซอร์ที่สนับสนุน",
    "Continue with this unsupported browser" : "ดำเนินการต่อด้วยเบราว์เซอร์นี้ที่ไม่สนับสนุน",
    "Supported versions" : "รุ่นที่สนับสนุน",
    "{name} version {version} and above" : "{name} รุ่น {version} ขึ้นไป",
    "Search {types} …" : "ค้นหา {types} …",
    "Choose {file}" : "เลือก {file}",
    "Choose" : "เลือก",
    "Copy to {target}" : "คัดลอกไปยัง {target}",
    "Copy" : "คัดลอก",
    "Move to {target}" : "ย้ายไปยัง {target}",
    "Move" : "ย้าย",
    "OK" : "ตกลง",
    "read-only" : "อ่านอย่างเดียว",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} ไฟล์มีข้อขัดแย้ง"],
    "One file conflict" : "หนึ่งไฟล์มีข้อขัดแย้ง",
    "New Files" : "ไฟล์ใหม่",
    "Already existing files" : "ไฟล์ที่มีอยู่เดิม",
    "Which files do you want to keep?" : "คุณต้องการเก็บไฟล์ไหน?",
    "If you select both versions, the copied file will have a number added to its name." : "ถ้าคุณเลือกทั้งสองรุ่น ชื่อของไฟล์ที่ถูกคัดลอกจะมีตัวเลขเพิ่มเข้าไป",
    "Cancel" : "ยกเลิก",
    "Continue" : "ดำเนินการต่อ",
    "(all selected)" : "(เลือกทั้งหมด)",
    "({count} selected)" : "(เลือก {count} รายการ)",
    "Error loading file exists template" : "เกิดข้อผิดพลาดขณะโหลดไฟล์เทมเพลตที่มีอยู่",
    "Saving …" : "กำลังบันทึก …",
    "seconds ago" : "วินาทีที่แล้ว",
    "Connection to server lost" : "การเชื่อมต่อไปยังเซิร์ฟเวอร์สูญหาย",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["เกิดปัญหาขณะโหลดหน้าเว็บ จะโหลดหน้าเว็บใหม่ใน %n วินาที"],
    "Add to a project" : "เพิ่มไปยังโครงการ",
    "Show details" : "แสดงข้อมูล",
    "Hide details" : "ซ่อนข้อมูล",
    "Rename project" : "เปลี่ยนชื่อโครงการ",
    "Failed to rename the project" : "ไม่สามารถเปลี่ยนชื่อโครงการ",
    "Failed to create a project" : "ไม่สามารถสร้างโครงการ",
    "Failed to add the item to the project" : "ไม่สามารถเพิ่มรายการเข้าสู่โครงการ",
    "Connect items to a project to make them easier to find" : "เชื่อมต่อรายการต่าง ๆ เข้าสู่โครงการเพื่อให้หาได้ง่ายขึ้น",
    "Type to search for existing projects" : "พิมพ์เพื่อค้นหาโครงการที่มีอยู่",
    "New in" : "ใหม่ใน",
    "View changelog" : "ดูบันทึกการเปลี่ยนแปลง",
    "Very weak password" : "รหัสผ่านระดับต่ำมาก",
    "Weak password" : "รหัสผ่านระดับต่ำ",
    "So-so password" : "รหัสผ่านระดับปกติ",
    "Good password" : "รหัสผ่านระดับดี",
    "Strong password" : "รหัสผ่านระดับดีมาก",
    "No action available" : "ไม่มีการกระทำที่ใช้ได้",
    "Error fetching contact actions" : "เกิดข้อผิดพลาดในการดึงการกระทำรายชื่อ",
    "Close \"{dialogTitle}\" dialog" : "ปิดกล่องโต้ตอบ \"{dialogTitle}\"",
    "Non-existing tag #{tag}" : "แท็ก #{tag} ไม่มีอยู่",
    "Restricted" : "ถูกจำกัด",
    "Invisible" : "มองไม่เห็น",
    "Delete" : "ลบ",
    "Rename" : "เปลี่ยนชื่อ",
    "Collaborative tags" : "แท็กแบบทำงานร่วมกัน",
    "No tags found" : "ไม่พบแท็ก",
    "Personal" : "ส่วนตัว",
    "Accounts" : "บัญชี",
    "Admin" : "ผู้ดูแลระบบ",
    "Help" : "ช่วยเหลือ",
    "Access forbidden" : "ไม่ได้รับอนุญาตให้เข้าถึง",
    "Profile not found" : "ไม่พบโปรไฟล์",
    "The profile does not exist." : "โปรไฟล์นี้ไม่มีอยู่",
    "Back to %s" : "กลับสู่ %s",
    "Page not found" : "ไม่พบหน้า",
    "The page could not be found on the server or you may not be allowed to view it." : "ไม่พบหน้านี้บนเซิร์ฟเวอร์ หรือคุณอาจไม่ได้รับอนุญาตให้ดูหน้านี้",
    "Too many requests" : "มีคำขอมากเกินไป",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "มีการส่งคำขอจากเครือข่ายของคุณมากเกินไป กรุณาลองอีกครั้งในภายหลัง หรือติดต่อผู้ดูแลระบบหากเป็นข้อผิดพลาด",
    "Error" : "ข้อผิดพลาด",
    "Previous" : "ก่อนหน้า",
    "Internal Server Error" : "ข้อผิดพลาดภายในเซิร์ฟเวอร์",
    "The server was unable to complete your request." : "เซิร์ฟเวอร์ไม่สามารถดำเนินการคำขอของคุณได้",
    "If this happens again, please send the technical details below to the server administrator." : "หากพบปัญหานี้อีก โปรดส่งข้อมูลทางเทคนิคด้านล่างไปให้ผู้ดูแลเซิร์ฟเวอร์",
    "More details can be found in the server log." : "รายละเอียดเพิ่มเติมสามารถดูได้ที่บันทึกของระบบเซิร์ฟเวอร์",
    "Technical details" : "รายละเอียดทางเทคนิค",
    "Remote Address: %s" : "ที่อยู่รีโมท: %s",
    "Request ID: %s" : "ID คำขอ: %s",
    "Type: %s" : "ชนิด: %s",
    "Code: %s" : "โค้ด: %s",
    "Message: %s" : "ข้อความ: %s",
    "File: %s" : "ไฟล์: %s",
    "Line: %s" : "บรรทัด: %s",
    "Trace" : "ร่องรอย",
    "Security warning" : "คำเตือนความปลอดภัย",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "ไดเรกทอรี data และไฟล์ของคุณอาจเข้าถึงได้จากอินเทอร์เน็ต เพราะไฟล์ .htaccess ไม่ทำงาน",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "สำหรับวิธีการกำหนดค่าเซิร์ฟเวอร์ของคุณอย่างถูกต้อง โปรดดู<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">เอกสารประกอบ</a>",
    "Create an <strong>admin account</strong>" : "สร้าง<strong>บัญชีผู้ดูแลระบบ</strong>",
    "Show password" : "แสดงรหัสผ่าน",
    "Toggle password visibility" : "เปิด-ปิด การมองเห็นรหัสผ่าน",
    "Storage & database" : "พื้นที่จัดเก็บข้อมูลและฐานข้อมูล",
    "Data folder" : "โฟลเดอร์เก็บข้อมูล",
    "Configure the database" : "ตั้งค่าฐานข้อมูล",
    "Only %s is available." : "เฉพาะ %s สามารถใช้ได้",
    "Install and activate additional PHP modules to choose other database types." : "ติดตั้งและเปิดใช้งานโมดูล PHP เพิ่มเติมเพื่อเลือกชนิดฐานข้อมูลอื่น ๆ",
    "For more details check out the documentation." : "สำหรับรายละเอียดเพิ่มเติมสามารถตรวจสอบได้ที่<a href=\"%s\" target=\"_blank\">เอกสารประกอบ</a>",
    "Database account" : "บัญชีฐานข้อมูล",
    "Database password" : "รหัสผ่านฐานข้อมูล",
    "Database name" : "ชื่อฐานข้อมูล",
    "Database tablespace" : "พื้นที่ตารางในฐานข้อมูล",
    "Database host" : "โฮสต์ฐานข้อมูล",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "โปรดระบุหมายเลขพอร์ตพร้อมชื่อโฮสต์ (เช่น localhost:5432)",
    "Performance warning" : "คำเตือนเรื่องประสิทธิภาพ",
    "You chose SQLite as database." : "คุณเลือก SQLite เป็นฐานข้อมูล",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "ควรใช้ SQLite เฉพาะการทำงานขนาดเล็กและการพัฒนาเท่านั้น สำหรับการใช้งานจริง เราแนะนำให้ใช้แบ็กเอนด์ฐานข้อมูลแบบอื่น",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "หากคุณใช้ไคลเอ็นต์เพื่อซิงค์ไฟล์ ไม่แนะนำให้ใช้ SQLite อย่างยิ่ง",
    "Install" : "ติดตั้ง",
    "Installing …" : "กำลังติดตั้ง …",
    "Need help?" : "ต้องการความช่วยเหลือ?",
    "See the documentation" : "ดูเอกสารประกอบ",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "ดูเหมือนว่าคุณกำลังพยายามติดตั้ง Nextcloud ใหม่ แต่ในไดเรกทอรี config ของคุณไม่มีไฟล์ CAN_INSTALL โปรดสร้างไฟล์ CAN_INSTALL ในโฟลเดอร์ config ของคุณก่อนดำเนินการต่อ",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "ไม่สามารถลบไฟล์ CAN_INSTALL จากโฟลเดอร์ config โปรดลบไฟล์นี้ออกด้วยตัวเอง",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "โปรแกรมนี้ต้องการ JavaScript สำหรับการทำงานที่ถูกต้อง กรุณา{linkstart}เปิดใช้งาน JavaScript{linkend} และโหลดหน้าเว็บใหม่",
    "Skip to main content" : "ข้ามไปที่เนื้อหาหลัก",
    "Skip to navigation of app" : "ข้ามไปที่การนำทางของแอป",
    "Go to %s" : "ไปที่ %s",
    "Get your own free account" : "รับบัญชีฟรีของคุณ",
    "Connect to your account" : "เชื่อมต่อบัญชีของคุณ",
    "Please log in before granting %1$s access to your %2$s account." : "กรุณาเข้าสู่ระบบก่อนอนุญาตให้ %1$s เข้าถึงบัญชี %2$s ของคุณ",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "หากคุณไม่ได้เป็นคนตั้งค่าอุปกรณ์หรือแอปใหม่ อาจมีบุคคลอื่นกำลังหลอกให้คุณอนุญาตให้พวกเขาเข้าถึงข้อมูลของคุณ ในกรณีนี้ห้ามดำเนินการต่อ ให้ติดต่อผู้ดูแลระบบของคุณ",
    "App password" : "รหัสผ่านแอป",
    "Grant access" : "อนุญาตให้เข้าถึง",
    "Alternative log in using app password" : "การเข้าสู่ระบบทางเลือกโดยใช้รหัสผ่านแอป",
    "Account access" : "การเข้าถึงบัญชี",
    "Currently logged in as %1$s (%2$s)." : "ขณะนี้เข้าสู่ระบบเป็น %1$s (%2$s)",
    "You are about to grant %1$s access to your %2$s account." : "คุณกำลังจะอนุญาตให้ %1$s เข้าถึงบัญชี %2$s ของคุณ",
    "Account connected" : "เชื่อมต่อบัญชีแล้ว",
    "Your client should now be connected!" : "ไคลเอ็นต์ของคุณควรได้รับการเชื่อมต่อแล้ว",
    "You can close this window." : "คุณสามารถปิดหน้าต่างนี้ได้",
    "This share is password-protected" : "การแชร์นี้มีการป้องกันด้วยรหัสผ่าน",
    "The password is wrong or expired. Please try again or request a new one." : "รหัสผ่านไม่ถูกต้องหรือหมดอายุ กรุณาลองอีกครั้งหรือขอรหัสผ่านใหม่",
    "Please type in your email address to request a temporary password" : "กรุณาพิมพ์ที่อยู่อีเมลของคุณเพื่อขอรหัสผ่านชั่วคราว",
    "Email address" : "ที่อยู่อีเมล",
    "Password sent!" : "ส่งรหัสผ่านแล้ว!",
    "You are not authorized to request a password for this share" : "คุณไม่ได้รับอนุญาตให้ขอรหัสผ่านสำหรับแชร์นี้",
    "Two-factor authentication" : "การยืนยันสองปัจจัย",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "ความปลอดภัยขั้นสูงถูกเปิดสำหรับบัญชีของคุณ เลือกปัจจัยที่สองเพื่อรับรองความถูกต้อง:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "ไม่สามารถโหลดหนึ่งในวิธียืนยันสองปัจจัยของคุณ กรุณาติดต่อผู้ดูแลระบบ",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "การยืนยันสองปัจจัยเปิดอยู่ แต่ยังไม่ได้กำหนดค่าในบัญชีของคุณ กรุณาติดต่อผู้ดูแลระบบเพื่อขอความช่วยเหลือ",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "การยืนยันสองปัจจัยเปิดอยู่ แต่ยังไม่ได้กำหนดค่าในบัญชีของคุณ กรุณาดำเนินการต่อเพื่อตั้งค่าการยืนยันสองปัจจัย",
    "Set up two-factor authentication" : "ตั้งค่าการยืนยันสองปัจจัย",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "การยืนยันสองปัจจัยเปิดอยู่ แต่ยังไม่ได้กำหนดค่าในบัญชีของคุณ กรุณาใช้หนึ่งในรหัสสำรองที่คุณมี หรือติดต่อผู้ดูแลระบบเพื่อขอความช่วยเหลือ",
    "Use backup code" : "ใช้รหัสสำรอง",
    "Cancel login" : "ยกเลิกการเข้าสู่ระบบ",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "ความปลอดภัยขั้นสูงถูกเปิดสำหรับบัญชีของคุณ เลือกผู้ให้บริการที่จะตั้งค่า:",
    "Error while validating your second factor" : "ข้อผิดพลาดขณะตรวจสอบปัจจัยที่สอง",
    "Access through untrusted domain" : "เข้าใช้งานผ่านโดเมนที่ไม่เชื่อถือ",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "กรุณาติดต่อผู้ดูแลระบบของคุณ ถ้าคุณเป็นผู้ดูแลระบบ ให้แก้ไขการตั้งค่า \"trusted_domains\" ใน config/config.php ตามตัวอย่างใน config.sample.php",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "ข้อมูลเพิ่มเติมสำหรับวิธีการกำหนดค่านี้อยู่ใน%1$sเอกสารประกอบ%2$s",
    "App update required" : "จำเป็นต้องอัปเดตแอป",
    "%1$s will be updated to version %2$s" : "%1$s จะถูกอัปเดตเป็นรุ่น %2$s",
    "The following apps will be updated:" : "แอปต่อไปนี้จะถูกอัปเดต:",
    "These incompatible apps will be disabled:" : "แอปเหล่านี้เข้ากันไม่ได้ และจะถูกปิดการใช้งาน:",
    "The theme %s has been disabled." : "ธีม %s ถูกปิดการใช้งาน",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "โปรดตรวจสอบว่าได้ทำการสำรองข้อมูลของฐานข้อมูล โฟลเดอร์ config และโฟลเดอร์ data ก่อนดำเนินการ",
    "Start update" : "เริ่มต้นอัปเดต",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "เพื่อหลีกเลี่ยงการหมดเวลากับการติดตั้งขนาดใหญ่ คุณสามารถเรียกใช้คำสั่งต่อไปนี้จากไดเรกทอรีการติดตั้งของคุณ:",
    "Detailed logs" : "บันทึกอย่างละเอียด",
    "Update needed" : "จำเป็นต้องอัปเดต",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "สำหรับความช่วยเหลือ ดู<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">เอกสารประกอบ</a>",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "ฉันทราบว่าการดำเนินการอัปเดตผ่าน UI เว็บมีความเสี่ยง และหากคำขอหมดเวลาอาจทำให้ข้อมูลสูญหาย แต่ฉันได้สำรองข้อมูลไว้แล้วและทราบวิธีการกู้คืนข้อมูลหากเกิดข้อผิดพลาด",
    "Upgrade via web on my own risk" : "อัปเกรดผ่านเว็บบนความเสี่ยงของฉัน",
    "Maintenance mode" : "โหมดการบำรุงรักษา",
    "This %s instance is currently in maintenance mode, which may take a while." : "เซิร์ฟเวอร์ %s นี้อยู่ในโหมดการบำรุงรักษา ซึ่งอาจใช้เวลาสักครู่",
    "This page will refresh itself when the instance is available again." : "หน้านี้จะรีเฟรชตัวเองเมื่อเซิร์ฟเวอร์สามารถใช้ได้อีกครั้ง",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "ติดต่อผู้ดูแลระบบของคุณหากข้อความนี้ยังคงอยู่หรือปรากฏโดยไม่คาดคิด",
    "The user limit of this instance is reached." : "ถึงขีดจำกัดจำนวนผู้ใช้ของเซิร์ฟเวอร์นี้แล้ว",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "เว็บเซิร์ฟเวอร์ของคุณยังไม่ถูกตั้งค่าอย่างถูกต้องเพื่ออนุญาตการซิงโครไนซ์ไฟล์ เนื่องจากส่วนติดต่อ WebDAV อาจมีปัญหา",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "เซิร์ฟเวอร์เว็บของคุณไม่ได้ตั้งค่าอย่างถูกต้องเพื่อส่งไฟล์ .woff2 ซึ่งเป็นปัญหาที่พบบ่อยในการกำหนดค่า Nginx สำหรับ Nextcloud 15 จำเป็นต้องปรับแต่งเพื่อส่งไฟล์ .woff2 ด้วย โปรดเปรียบเทียบการกำหนดค่า Nginx ของคุณกับการกำหนดค่าที่แนะนำใน{linkstart}เอกสารประกอบ ↗{linkend} ของเรา",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "ส่วนหัว HTTP \"{header}\" ไม่ได้กำหนดค่าให้เท่ากับ \"{expected}\" ดังนั้นจึงมีความเสี่ยงด้านความปลอดภัยหรือความเป็นส่วนตัวที่เป็นไปได้ เราแนะนำให้ปรับการตั้งค่านี้",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "ส่วนหัว HTTP \"{header}\" ไม่ได้กำหนดค่าให้เท่ากับ \"{expected}\" คุณสมบัติบางอย่างอาจไม่สามารถทำงานตามปกติ เราแนะนำให้ปรับการตั้งค่านี้",
    "Currently open" : "เปิดอยู่ในขณะนี้",
    "Wrong username or password." : "ชื่อผู้ใช้หรือรหัสผ่านไม่ถูกต้อง",
    "User disabled" : "ผู้ใช้ถูกปิดใช้งาน",
    "Username or email" : "ชื่อผู้ใช้หรืออีเมล",
    "Error loading message template: {error}" : "เกิดข้อผิดพลาดขณะกำลังโหลดเทมเพลตข้อความ: {error} ",
    "Users" : "ผู้ใช้",
    "Username" : "ชื่อผู้ใช้",
    "Database user" : "ชื่อผู้ใช้ฐานข้อมูล",
    "This action requires you to confirm your password" : "การกระทำนี้จำเป็นให้คุณยืนยันรหัสผ่าน",
    "Confirm your password" : "ยืนยันรหัสผ่านของคุณ",
    "Confirm" : "ยืนยัน",
    "App token" : "โทเค็นแอป",
    "Alternative log in using app token" : "ทางเลือกเข้าสู่ระบบด้วยโทเค็นแอป",
    "Please use the command line updater because you have a big instance with more than 50 users." : "กรุณาใช้ตัวอัปเดตผ่านบรรทัดคำสั่ง เนื่องจากคุณมีเซิร์ฟเวอร์ขนาดใหญ่ที่มีจำนวนผู้ใช้มากกว่า 50 ผู้ใช้"
},
"nplurals=1; plural=0;");
